import { inject, Injectable } from '@angular/core';
import { AuthConfig, OAuthService } from 'angular-oauth2-oidc';
import { UserService } from './user.service';
import { User } from '../model/User';
import { Router } from '@angular/router';
import { environment } from '../../environments/environment';


@Injectable({
  providedIn: 'root',
})
export class AuthService {
  private readonly authConfig: AuthConfig = {
    issuer: 'https://oauth.simonis.lol/application/o/casino-dev/',
    clientId: environment.OAUTH_CLIENT_ID,
    dummyClientSecret: environment.OAUTH_CLIENT_SECRET,
    scope: `openid email profile ${environment.OAUTH_CLIENT_ID}`,
    responseType: 'code',
    redirectUri: window.location.origin + '/auth/callback',
    oidc: true,
    requestAccessToken: true,
    strictDiscoveryDocumentValidation: false,
    skipIssuerCheck: true,
    disableAtHashCheck: true,
  };

  private userService: UserService = inject(UserService);
  private oauthService: OAuthService = inject(OAuthService);
  private router: Router = inject(Router);

  private user: User | null = null;

  constructor() {
    this.oauthService.configure(this.authConfig);
    this.oauthService.events.subscribe((event) => {
      if (event.type === 'token_received') {
        this.oauthService.loadUserProfile().then((profile) => {
          console.log(profile);
          this.fromUserProfile(profile).subscribe((user) => {
            this.user = user;
            this.router.navigate(['home']);
          });
        });
      }
    });
    this.oauthService.loadDiscoveryDocumentAndTryLogin().then(() => {
    });
  }

  login() {
    this.oauthService.initLoginFlow();
  }

  logout() {
    this.oauthService.logOut();
  }

  isLoggedIn() {
    return this.oauthService.hasValidAccessToken();
  }

  private fromUserProfile(profile: object) {
    return this.userService.getOrCreateUser(profile);
  }

  getAccessToken() {
    return this.oauthService.getAccessToken();
  }
  getUser() {
    return this.user;
  }
}
